@@ -28,17 +28,26 @@
 
 #include <cairo.h>
 
+/* Normal shadings */
 #define SHADE_TOP 1.08
 #define SHADE_CENTER_TOP 1.02
 #define SHADE_BOTTOM 0.94
 
-#define LIGHT_SHADE_TOP 1.06
-#define LIGHT_SHADE_CENTER_TOP 1.02
-#define LIGHT_SHADE_BOTTOM 0.96
-
+/* Topleft highlight */
 #define TOPLEFT_HIGHLIGHT_SHADE 1.3
 #define TOPLEFT_HIGHLIGHT_ALPHA 0.4
 
+/* Listview */
+#define LISTVIEW_SHADE_TOP 1.06
+#define LISTVIEW_SHADE_CENTER_TOP 1.02
+#define LISTVIEW_SHADE_BOTTOM 0.96
+
+/* Toolbar */
+#define TOOLBAR_SHADE_TOP 1.05
+#define TOOLBAR_SHADE_CENTER_TOP 1.01
+#define TOOLBAR_SHADE_BOTTOM 0.96
+
+
 static void
 clearlooks_draw_gummy_gradient (cairo_t          *cr,
                                 double x, double y, int width, int height,
@@ -63,7 +72,7 @@ clearlooks_draw_gummy_gradient (cairo_t          *cr,
 	cairo_set_source (cr, pt);
 	ge_cairo_rounded_rectangle (cr, x, y, width, height, radius, corners);
 	cairo_fill (cr);
-	
+
 	cairo_pattern_destroy (pt);
 }
 
@@ -94,42 +103,42 @@ clearlooks_gummy_draw_highlight_and_shade (cairo_t                *cr,
 	/* not really sure of shading ratios... we will think */
 	ge_shade_color (bg_color, 0.8, &shadow);
 	ge_shade_color (bg_color, 1.2, &highlight);
-	
+
 	cairo_save (cr);
-	
+
 	/* Top/Left highlight */
 	if (corners & CR_CORNER_BOTTOMLEFT)
 		cairo_move_to (cr, x, y+height-radius);
 	else
 		cairo_move_to (cr, x, y+height);
-	
+
 	ge_cairo_rounded_corner (cr, x, y, radius, corners & CR_CORNER_TOPLEFT);
 
 	if (corners & CR_CORNER_TOPRIGHT)
 		cairo_line_to (cr, x+width-radius, y);
 	else
 		cairo_line_to (cr, x+width, y);
-	
+
 	if (params->shadow & CL_SHADOW_OUT)
 		cairo_set_source_rgba (cr, highlight.r, highlight.g, highlight.b, 0.5);
 	else
 		cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.5);
 		
 	cairo_stroke (cr);
-	
+
 	/* Bottom/Right highlight -- this includes the corners */
 	cairo_move_to (cr, x+width-radius, y); /* topright and by radius to the left */
 	ge_cairo_rounded_corner (cr, x+width, y, radius, corners & CR_CORNER_TOPRIGHT);
 	ge_cairo_rounded_corner (cr, x+width, y+height, radius, corners & CR_CORNER_BOTTOMRIGHT);
 	ge_cairo_rounded_corner (cr, x, y+height, radius, corners & CR_CORNER_BOTTOMLEFT);
-	
+
 	if (params->shadow & CL_SHADOW_OUT)
 		cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.5);
 	else
 		cairo_set_source_rgba (cr, highlight.r, highlight.g, highlight.b, 0.5);
-	
+
 	cairo_stroke (cr);
-	
+
 	cairo_restore (cr);
 }
 
@@ -168,7 +177,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	double radius;
 
 	cairo_pattern_t *pattern;
-	
+
 	cairo_save (cr);
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
@@ -215,7 +224,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 			clearlooks_set_mixed_color (cr, &params->parentbg, &shadow, 0.5);
 			cairo_stroke (cr);
 		}
-		
+
 		if (!(params->enable_glow && !params->active && !params->disabled))
 			params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width-1, height-1, params->radius+1, params->corners);
 		cairo_translate (cr, -0.5, -0.5);
@@ -224,7 +233,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 	clearlooks_draw_gummy_gradient (cr, xoffset+1, yoffset+1, 
 	                              width-(xoffset*2)-2, height-(yoffset*2)-2, 
 	                              &fill, params->disabled, radius, params->corners);
-	
+
 	/* Pressed button shadow */
 	if (params->active)
 	{
@@ -237,16 +246,16 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 		                            params->corners & (CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMLEFT));
 		cairo_clip (cr);
 		cairo_rectangle (cr, xoffset+1, yoffset+1, width-(xoffset*2)-2, 3);
-	
+
 		pattern = cairo_pattern_create_linear (xoffset+1, yoffset+1, xoffset+1, yoffset+4);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.0, shadow.r, shadow.g, shadow.b, 0.58);
 		cairo_pattern_add_color_stop_rgba (pattern, 1.0, shadow.r, shadow.g, shadow.b, 0.0);
 		cairo_set_source (cr, pattern);
 		cairo_fill (cr);
 		cairo_pattern_destroy (pattern);
-		
+
 		cairo_rectangle (cr, xoffset+1, yoffset+1, 3, height-(yoffset*2)-2);
-	
+
 		pattern = cairo_pattern_create_linear (xoffset+1, yoffset+1, xoffset+4, yoffset+1);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.0, shadow.r, shadow.g, shadow.b, 0.58);
 		cairo_pattern_add_color_stop_rgba (pattern, 1.0, shadow.r, shadow.g, shadow.b, 0.0);
@@ -256,7 +265,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 
 		cairo_restore (cr);
 	}
-	
+
 	/* Border */
 	if (params->is_default) /* || (params->prelight && params->enable_glow)) */
 		border_normal = colors->spot[2];
@@ -286,13 +295,13 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	const CairoColor *base = &colors->base[params->state_type];
 	CairoColor border = colors->shade[params->disabled ? 4 : 6];
 	double radius = MIN (params->radius, MIN ((width - 4.0) / 2.0, (height - 4.0) / 2.0));
-	
+
 	if (params->focus)
 		border = colors->spot[2];
 
 	cairo_translate (cr, x+0.5, y+0.5);
 	cairo_set_line_width (cr, 1.0);
-	
+
 	/* Fill the background (shouldn't have to) */
 	cairo_rectangle (cr, -0.5, -0.5, width, height);
 	ge_cairo_set_color (cr, &params->parentbg);
@@ -302,7 +311,7 @@ clearlooks_gummy_draw_entry (cairo_t                *cr,
 	cairo_rectangle (cr, 1.5, 1.5, width-4, height-4);
 	ge_cairo_set_color (cr, base);
 	cairo_fill (cr);
-	
+
 	params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width-1, height-1, radius+1, params->corners);
 
 	/* Draw the inner shadow */
@@ -344,14 +353,14 @@ clearlooks_gummy_draw_progressbar_trough (cairo_t                *cr,
 	CairoColor        shadow;
 	cairo_pattern_t  *pattern;
 	double            radius = MIN (params->radius, MIN ((height-2.0) / 2.0, (width-2.0) / 2.0));
-	
+
 	cairo_save (cr);
 
 	cairo_set_line_width (cr, 1.0);
-	
+
 	/* Fill with bg color */
 	ge_cairo_set_color (cr, &colors->bg[params->state_type]);
-	
+
 	cairo_rectangle (cr, x, y, width, height);
 	cairo_fill (cr);
 
@@ -425,7 +434,7 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
 
 	stroke_width = height*2;
 	x_step = (((float)stroke_width/10)*offset); /* This looks weird ... */
-	
+
 	cairo_translate (cr, x, y);
 
 	cairo_save (cr);
@@ -460,12 +469,12 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
 		cairo_translate (cr, stroke_width, 0);
 		tile_pos += stroke_width;
 	}
-	
+
 	cairo_set_source_rgba (cr, colors->spot[2].r,
 	                           colors->spot[2].g,
 	                           colors->spot[2].b,
 	                           0.15);
-	
+
 	cairo_fill (cr);
 	cairo_restore (cr); /* rounded clip region */
 
@@ -543,7 +552,7 @@ clearlooks_gummy_draw_progressbar_fill (cairo_t                     *cr,
 		ge_cairo_set_color (cr, &shadow);
 		cairo_stroke (cr);
 	}
-	
+
 	cairo_restore (cr);
 
 	cairo_restore (cr); /* rotation, mirroring */
@@ -557,9 +566,9 @@ clearlooks_gummy_scale_draw_gradient (cairo_t          *cr,
                                       gboolean horizontal, gboolean in)
 {
 	cairo_pattern_t *pattern;
-	
+
 	CairoColor f1, f2;
-	
+
 	ge_shade_color (fill, in? 0.95 : 1.1, &f1);
 	ge_shade_color (fill, in? 1.05 : 0.9, &f2);
 
@@ -571,7 +580,7 @@ clearlooks_gummy_scale_draw_gradient (cairo_t          *cr,
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
-	
+
 	clearlooks_set_mixed_color (cr, border, fill, 0.2);
 	ge_cairo_stroke_rectangle (cr, x, y, width, height);
 }
@@ -591,7 +600,7 @@ clearlooks_gummy_draw_scale_trough (cairo_t                *cr,
 	{
 		trough_width  = width-3;
 		trough_height = TROUGH_SIZE-2;
-		
+
 		translate_x   = x + 0.5;
 		translate_y   = y + 0.5 + (height/2) - (TROUGH_SIZE/2);
 	}
@@ -599,19 +608,19 @@ clearlooks_gummy_draw_scale_trough (cairo_t                *cr,
 	{
 		trough_width  = TROUGH_SIZE-2;
 		trough_height = height-3;
-		
+
 		translate_x   = x + 0.5 + (width/2) - (TROUGH_SIZE/2);
 		translate_y  = y + 0.5;
 	}
 
 	cairo_set_line_width (cr, 1.0);
 	cairo_translate (cr, translate_x, translate_y);
-	
+
 	if (!slider->fill_level)
 		params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, trough_width+2, trough_height+2, 0, 0);
-	
+
 	cairo_translate (cr, 1, 1);
-	
+
 	if (!slider->lower && !slider->fill_level)
 		clearlooks_gummy_scale_draw_gradient (cr, 
 		                                      &colors->shade[2], /* bottom */
@@ -654,7 +663,7 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	const CairoColor    *fill;
 
 	cairo_pattern_t     *pattern;
-	
+
 	double               radius;
 	double               strip_size;
 
@@ -674,39 +683,39 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	if (tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM)
 	{
 		height += 3.0;
-	 	strip_size = 2.0/height; /* 2 pixel high strip */
-		
+		strip_size = 2.0/height; /* 2 pixel high strip */
+
 		if (tab->gap_side == CL_GAP_TOP)
 			cairo_translate (cr, 0.0, -3.0); /* gap at the other side */
 	}
 	else
 	{
 		width += 3.0;
-	 	strip_size = 2.0/width;
-		
+		strip_size = 2.0/width;
+
 		if (tab->gap_side == CL_GAP_LEFT) 
 			cairo_translate (cr, -3.0, 0.0); /* gap at the other side */
 	}
-	
+
 	/* Set the fill color */
 	fill = &colors->bg[params->state_type];
 
 	/* Set tab shape */
 	ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1,
 	                            radius, params->corners);
-	
+
 	/* Draw fill */
 	ge_cairo_set_color (cr, fill);
-	cairo_fill   (cr);
+	cairo_fill  (cr);
 
 	/* Draw highlight */
 	if (!params->active)
 	{
 		ShadowParameters shadow;
-		
+
 		shadow.shadow  = CL_SHADOW_OUT;
 		shadow.corners = params->corners;
-		
+
 		clearlooks_gummy_draw_highlight_and_shade (cr, &colors->bg[0], &shadow,
 		                                     width, height, radius);
 	}
@@ -715,20 +724,20 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	{
 		CairoColor hilight;
 		CairoColor shade1, shade2, shade3;
-		
+
 		pattern = cairo_pattern_create_linear (tab->gap_side == CL_GAP_LEFT   ? width-1  : 0,
 		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 1,
 		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 0,
 		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 0);
 
 		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
-		
+
 		ge_shade_color (fill, 1.14, &hilight);
 		ge_shade_color (fill, SHADE_TOP, &shade1);
 		ge_shade_color (fill, SHADE_CENTER_TOP, &shade2);
 		ge_shade_color (fill, SHADE_BOTTOM, &shade3);
 
-		cairo_pattern_add_color_stop_rgb (pattern, 0.0,        hilight.r, hilight.g, hilight.b);     
+		cairo_pattern_add_color_stop_rgb (pattern, 0.0,        hilight.r, hilight.g, hilight.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0/height, hilight.r, hilight.g, hilight.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0/height, shade1.r, shade1.g, shade1.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.45,       shade2.r, shade2.g, shade2.b);
@@ -745,9 +754,9 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 0,
 		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 0,
 		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 0);
-	
+
 		ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
-		
+
 		cairo_pattern_add_color_stop_rgba (pattern, 0.0, stripe_fill->r, stripe_fill->g, stripe_fill->b, 0.5);
 		cairo_pattern_add_color_stop_rgba (pattern, 0.8, fill->r, fill->g, fill->b, 0.0);
 		cairo_set_source (cr, pattern);
@@ -756,7 +765,7 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 	}
 
 	ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1, radius, params->corners);
-	
+
 	if (params->active)
 	{
 		ge_cairo_set_color (cr, border);
@@ -768,7 +777,7 @@ clearlooks_gummy_draw_tab (cairo_t                *cr,
 		                                       tab->gap_side == CL_GAP_TOP    ? height-2 : 2,
 		                                       tab->gap_side == CL_GAP_RIGHT  ? width    : 2,
 		                                       tab->gap_side == CL_GAP_BOTTOM ? height   : 2);
-		
+
 		cairo_pattern_add_color_stop_rgb (pattern, 0.0, stripe_border->r, stripe_border->g, stripe_border->b);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.8, border->r,        border->g,        border->b);
 		cairo_set_source (cr, pattern);
@@ -794,12 +803,12 @@ clearlooks_gummy_draw_separator (cairo_t                   *cr,
 	{
 		cairo_set_line_width  (cr, 1.0);
 		cairo_translate       (cr, x, y+0.5);
-		
+
 		cairo_move_to         (cr, 0.0,   0.0);
 		cairo_line_to         (cr, width, 0.0);
 		ge_cairo_set_color    (cr, color);
 		cairo_stroke          (cr);
-		
+
 		cairo_move_to         (cr, 0.0,   1.0);
 		cairo_line_to         (cr, width, 1.0);
 		ge_cairo_set_color    (cr, &hilight);
@@ -809,15 +818,15 @@ clearlooks_gummy_draw_separator (cairo_t                   *cr,
 	{
 		cairo_set_line_width  (cr, 1.0);
 		cairo_translate       (cr, x+0.5, y);
-		
+
 		cairo_move_to         (cr, 0.0, 0.0);
 		cairo_line_to         (cr, 0.0, height);
-		ge_cairo_set_color  (cr, color);
+		ge_cairo_set_color    (cr, color);
 		cairo_stroke          (cr);
-		
+
 		cairo_move_to         (cr, 1.0, 0.0);
 		cairo_line_to         (cr, 1.0, height);
-		ge_cairo_set_color  (cr, &hilight);
+		ge_cairo_set_color    (cr, &hilight);
 		cairo_stroke          (cr);
 	}
 
@@ -892,12 +901,12 @@ clearlooks_gummy_draw_slider_button (cairo_t                *cr,
 	double radius = MIN (params->radius, MIN ((width - 1.0) / 2.0, (height - 1.0) / 2.0));
 
 	cairo_set_line_width (cr, 1.0);
-	
+
 	if (!slider->horizontal)
 		ge_cairo_exchange_axis (cr, &x, &y, &width, &height);
 
 	cairo_translate (cr, x+0.5, y+0.5);
-	
+
 	params->style_functions->draw_shadow (cr, colors, radius, width-1, height-1);
 	params->style_functions->draw_slider (cr, colors, params, 1, 1, width-2, height-2);
 }
@@ -917,7 +926,7 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 	cairo_pattern_t *pattern;
 	ShadowParameters shadow;
 	double radius = MIN (widget->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
-	
+
 	if (scrollbar->horizontal)
 	{
 		if (stepper->stepper == CL_STEPPER_A)
@@ -932,22 +941,22 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
 	}
-	
+
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1);
-	
+
 	ge_cairo_rounded_rectangle (cr, 1, 1, width-2, height-2, radius, corners);
-	
+
 	if (scrollbar->horizontal)
 		pattern = cairo_pattern_create_linear (0, 0, 0, height);
 	else
 		pattern = cairo_pattern_create_linear (0, 0, width, 0);
-	
+
 	fill = colors->bg[widget->state_type];
 	ge_shade_color(&fill, SHADE_TOP, &shade1);
 	ge_shade_color(&fill, SHADE_CENTER_TOP, &shade2); 
 	ge_shade_color(&fill, SHADE_BOTTOM, &shade3); 
-	
+
 	cairo_pattern_add_color_stop_rgb(pattern, 0,   shade1.r, shade1.g, shade1.b);
 	cairo_pattern_add_color_stop_rgb(pattern, 0.5, shade2.r, shade2.g, shade2.b);
 	cairo_pattern_add_color_stop_rgb(pattern, 0.5, fill.r, fill.g, fill.b);
@@ -955,15 +964,15 @@ clearlooks_gummy_draw_scrollbar_stepper (cairo_t                          *cr,
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
-	
+
 	cairo_translate (cr, 0.5, 0.5);
 	clearlooks_gummy_draw_top_left_highlight (cr, &fill, widget, width, height, (stepper->stepper == CL_STEPPER_A) ? radius : 0);
 	cairo_translate (cr, -0.5, -0.5);
-	
+
 	ge_cairo_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, radius, corners);
 	clearlooks_set_mixed_color (cr, border, &fill, 0.2);
 	cairo_stroke (cr);
-	
+
 	cairo_translate (cr, 0.5, 0.5);
 	shadow.shadow  = CL_SHADOW_OUT;
 	shadow.corners = corners;
@@ -995,6 +1004,11 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 		ge_shade_color (&fill, 0.475, &border);
 	else
 		ge_shade_color (&fill, 0.575, &border);
+	/* The following lines increase contrast when the HUE is between 25 and 195, */
+	/* fixing a LOT of colorschemes! */
+	if (scrollbar->has_color && (hue_scroll < 195) && (hue_scroll > 25))
+		ge_shade_color (&border, 0.85, &border);
+
 	handles = border;
 	ge_mix_color (&border, &fill, scrollbar->has_color? 0.3 : 0.2, &border);
 
@@ -1018,7 +1032,7 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 		else
 			height += 1;
 	}
-	
+
 	if (!scrollbar->horizontal)
 		ge_cairo_exchange_axis (cr, &x, &y, &width, &height);
 
@@ -1026,14 +1040,14 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 
 	if (widget->prelight)
 		ge_shade_color (&fill, 1.04, &fill);
-	
+
 	cairo_set_line_width (cr, 1);
-	
+
 	ge_shade_color (&fill, TOPLEFT_HIGHLIGHT_SHADE, &hilight);
 	ge_shade_color (&fill, SHADE_TOP, &shade1);
 	ge_shade_color (&fill, SHADE_CENTER_TOP, &shade2);
 	ge_shade_color (&fill, SHADE_BOTTOM, &shade3);
-	
+
 	pattern = cairo_pattern_create_linear (1, 1, 1, height-2);
 	cairo_pattern_add_color_stop_rgb (pattern, 0,   shade1.r, shade1.g, shade1.b);
 	cairo_pattern_add_color_stop_rgb (pattern, 0.5, shade2.r, shade2.g, shade2.b);
@@ -1043,7 +1057,7 @@ clearlooks_gummy_draw_scrollbar_slider (cairo_t                   *cr,
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
-	
+
 	if (scrollbar->has_color) 
 	{
 		cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, 0.2);
@@ -1091,10 +1105,10 @@ clearlooks_gummy_draw_list_view_header (cairo_t                        *cr,
 
 	cairo_pattern_t *pattern;
 
- 	ge_shade_color (fill, 1.1, &hilight);
-	ge_shade_color (fill, LIGHT_SHADE_TOP, &shade1);
-	ge_shade_color (fill, LIGHT_SHADE_CENTER_TOP, &shade2);
-	ge_shade_color (fill, LIGHT_SHADE_BOTTOM, &shade3);
+	ge_shade_color (fill, 1.11, &hilight);
+	ge_shade_color (fill, LISTVIEW_SHADE_TOP, &shade1);
+	ge_shade_color (fill, LISTVIEW_SHADE_CENTER_TOP, &shade2);
+	ge_shade_color (fill, LISTVIEW_SHADE_BOTTOM, &shade3);
 
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
@@ -1113,28 +1127,28 @@ clearlooks_gummy_draw_list_view_header (cairo_t                        *cr,
 	cairo_fill (cr);
 
 	cairo_pattern_destroy (pattern);
-	
+
 	/* Draw highlight */
 	if (header->order == CL_ORDER_FIRST)
 	{
-		cairo_move_to (cr, 0.5, height-1);
+		cairo_move_to (cr, 0.5, height-1.5);
 		cairo_line_to (cr, 0.5, 0.5);
 	}
 	else
 		cairo_move_to (cr, 0.0, 0.5);
-	
+
 	cairo_line_to (cr, width, 0.5);
-	
-	cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, 0.5);
+
+	ge_cairo_set_color (cr, &hilight);
 	cairo_stroke (cr);
-	
+
 	/* Draw resize grip */
 	if ((params->ltr && header->order != CL_ORDER_LAST) ||
 	    (!params->ltr && header->order != CL_ORDER_FIRST) || header->resizable)
 	{
 		SeparatorParameters separator;
 		separator.horizontal = FALSE;
-		
+
 		if (params->ltr)
 			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
 			                                         width-1.5, 4.0, 2, height-8.0);
@@ -1154,19 +1168,19 @@ clearlooks_gummy_draw_toolbar (cairo_t                 *cr,
 	const CairoColor *fill = &colors->bg[GTK_STATE_NORMAL];
 	const CairoColor *dark = &colors->shade[3];
 	CairoColor light;
-	ge_shade_color (fill, 1.05, &light);
-	
+	ge_shade_color (fill, toolbar->style == 1 ? 1.1 : 1.05, &light);
+
 	cairo_set_line_width (cr, 1.0);
 	cairo_translate (cr, x, y);
-	
+
 	if (toolbar->style == 1) /* Enable Extra features */
-	{ 
+	{
 		cairo_pattern_t *pattern;
 		CairoColor shade1, shade2, shade3;
-		
-		ge_shade_color (fill, LIGHT_SHADE_TOP, &shade1);
-		ge_shade_color (fill, LIGHT_SHADE_CENTER_TOP, &shade2);
-		ge_shade_color (fill, LIGHT_SHADE_BOTTOM, &shade3);
+
+		ge_shade_color (fill, TOOLBAR_SHADE_TOP, &shade1);
+		ge_shade_color (fill, TOOLBAR_SHADE_CENTER_TOP, &shade2);
+		ge_shade_color (fill, TOOLBAR_SHADE_BOTTOM, &shade3);
 
 		/* Draw the fill */
 		pattern = cairo_pattern_create_linear (0, 0, 0, height);
@@ -1182,18 +1196,18 @@ clearlooks_gummy_draw_toolbar (cairo_t                 *cr,
 		cairo_pattern_destroy (pattern);
 	}
 	else /* Flat */
-	{ 
+	{
 		ge_cairo_set_color (cr, fill);
 		cairo_paint (cr);
+	}
 
-		if (!toolbar->topmost) 
-		{
-			/* Draw highlight */
-			cairo_move_to       (cr, 0, 0.5);
-			cairo_line_to       (cr, width-1, 0.5);
-			ge_cairo_set_color  (cr, &light);
-			cairo_stroke        (cr);
-		}
+	if (!toolbar->topmost)
+	{
+		/* Draw highlight */
+		cairo_move_to       (cr, 0, 0.5);
+		cairo_line_to       (cr, width-1, 0.5);
+		ge_cairo_set_color  (cr, &light);
+		cairo_stroke        (cr);
 	}
 
 	/* Draw shadow */
@@ -1348,19 +1362,19 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 	cairo_pattern_add_color_stop_rgba (pt, 0.5, shadow.r, shadow.b, shadow.g, 0.5);
 	cairo_pattern_add_color_stop_rgba (pt, 0.5, highlight.r, highlight.g, highlight.b, 0.5);
 	cairo_pattern_add_color_stop_rgb (pt, 1.0, highlight.r, highlight.g, highlight.b);
-	
+
 	cairo_translate (cr, x, y);
-	
+
 	cairo_set_line_width (cr, 2);
-	cairo_arc       (cr, 7, 7, 6, 0, G_PI*2);
+	cairo_arc (cr, 7, 7, 6, 0, G_PI*2);
 	cairo_set_source (cr, pt);
 	cairo_stroke (cr);
 	cairo_pattern_destroy (pt);
 
 	cairo_set_line_width (cr, 1);
 
-	cairo_arc       (cr, 7, 7, 5.5, 0, G_PI*2);
-	
+	cairo_arc (cr, 7, 7, 5.5, 0, G_PI*2);
+
 	if (!widget->disabled)
 	{
 		if (widget->prelight)
@@ -1369,10 +1383,10 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 			ge_cairo_set_color (cr, &colors->base[0]);
 		cairo_fill_preserve (cr);
 	}
-	
+
 	ge_cairo_set_color (cr, border);
 	cairo_stroke (cr);
-	
+
 	if (draw_bullet)
 	{
 		if (inconsistent)
@@ -1391,7 +1405,7 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 			cairo_arc (cr, 7, 7, 3, 0, G_PI*2);
 			ge_cairo_set_color (cr, dot);
 			cairo_fill (cr);
-		
+
 			cairo_arc (cr, 6, 6, 1, 0, G_PI*2);
 			cairo_set_source_rgba (cr, highlight.r, highlight.g, highlight.b, 0.5);
 			cairo_fill (cr);
@@ -1413,7 +1427,7 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 
 	inconsistent = (checkbox->shadow_type == GTK_SHADOW_ETCHED_IN);
 	draw_bullet |= inconsistent;
-	
+
 	if (widget->disabled)
 	{
 		border = &colors->shade[5];
@@ -1430,11 +1444,11 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1);
-	
+
 	if (widget->xthickness > 2 && widget->ythickness > 2)
 	{
 		widget->style_functions->draw_inset (cr, &widget->parentbg, 0.5, 0.5, 
-                                           width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
+                                  width-1, height-1, (widget->radius > 0)? 1 : 0, CR_CORNER_ALL);
 		
 		/* Draw the rectangle for the checkbox itself */
 		ge_cairo_rounded_rectangle (cr, 1.5, 1.5, 
@@ -1455,7 +1469,7 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 			ge_cairo_set_color (cr, &colors->base[0]);
 		cairo_fill_preserve (cr);
 	}
-	
+
 	ge_cairo_set_color (cr, border);
 	cairo_stroke (cr);
 
@@ -1472,13 +1486,13 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 			cairo_set_line_width (cr, 1.7);
 			cairo_move_to (cr, 0.5 + (width*0.2), (height*0.5));
 			cairo_line_to (cr, 0.5 + (width*0.4), (height*0.7));
-		
+
 			cairo_curve_to (cr, 0.5 + (width*0.4), (height*0.7),
 			                    0.5 + (width*0.5), (height*0.4),
 			                    0.5 + (width*0.70), (height*0.25));
 
 		}
-		
+
 		ge_cairo_set_color (cr, dot);
 		cairo_stroke (cr);
 	}
@@ -1491,7 +1505,7 @@ clearlooks_register_style_gummy (ClearlooksStyleFunctions *functions)
 	functions->draw_entry               = clearlooks_gummy_draw_entry;
 	functions->draw_progressbar_trough  = clearlooks_gummy_draw_progressbar_trough;
 	functions->draw_progressbar_fill    = clearlooks_gummy_draw_progressbar_fill;
-	functions->draw_scale_trough	    = clearlooks_gummy_draw_scale_trough;
+	functions->draw_scale_trough        = clearlooks_gummy_draw_scale_trough;
 	functions->draw_tab                 = clearlooks_gummy_draw_tab;
 	functions->draw_separator           = clearlooks_gummy_draw_separator;
 	functions->draw_slider              = clearlooks_gummy_draw_slider;
@@ -1500,10 +1514,10 @@ clearlooks_register_style_gummy (ClearlooksStyleFunctions *functions)
 	functions->draw_scrollbar_slider    = clearlooks_gummy_draw_scrollbar_slider;
 	functions->draw_list_view_header    = clearlooks_gummy_draw_list_view_header;
 	functions->draw_toolbar             = clearlooks_gummy_draw_toolbar;
-	functions->draw_menuitem      	    = clearlooks_gummy_draw_menuitem;
-	functions->draw_menubaritem   	    = clearlooks_gummy_draw_menubaritem;
-	functions->draw_selected_cell 	    = clearlooks_gummy_draw_selected_cell;
-	functions->draw_statusbar 	    = clearlooks_gummy_draw_statusbar;
+	functions->draw_menuitem            = clearlooks_gummy_draw_menuitem;
+	functions->draw_menubaritem         = clearlooks_gummy_draw_menubaritem;
+	functions->draw_selected_cell       = clearlooks_gummy_draw_selected_cell;
+	functions->draw_statusbar           = clearlooks_gummy_draw_statusbar;
 	functions->draw_checkbox            = clearlooks_gummy_draw_checkbox;
 	functions->draw_radiobutton         = clearlooks_gummy_draw_radiobutton;
 }
